==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementNotStatementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementNotStatementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property statements The statements to combine.
 */
public data class RuleGroupRuleStatementNotStatementArgs(
    public val statements: Output<List<RuleGroupRuleStatementArgs>>,
) : ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementNotStatementArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementNotStatementArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementNotStatementArgs.builder()
            .statements(
                statements.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RuleGroupRuleStatementNotStatementArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementNotStatementArgsBuilder internal constructor() {
    private var statements: Output<List<RuleGroupRuleStatementArgs>>? = null

    /**
     * @param value The statements to combine.
     */
    @JvmName("dvgfuxtsupuijcyu")
    public suspend fun statements(`value`: Output<List<RuleGroupRuleStatementArgs>>) {
        this.statements = value
    }

    @JvmName("uxsnnglvragltpjt")
    public suspend fun statements(vararg values: Output<RuleGroupRuleStatementArgs>) {
        this.statements = Output.all(values.asList())
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("svdhwbuihqhaofof")
    public suspend fun statements(values: List<Output<RuleGroupRuleStatementArgs>>) {
        this.statements = Output.all(values)
    }

    /**
     * @param value The statements to combine.
     */
    @JvmName("uxgwjuukjamojgrv")
    public suspend fun statements(`value`: List<RuleGroupRuleStatementArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("bmsudcbvvnauwdpx")
    public suspend
    fun statements(argument: List<suspend RuleGroupRuleStatementArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RuleGroupRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("jiijovmybwtispwk")
    public suspend fun statements(
        vararg
        argument: suspend RuleGroupRuleStatementArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RuleGroupRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("rgevfowbimwqarcu")
    public suspend fun statements(argument: suspend RuleGroupRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RuleGroupRuleStatementArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("yuuanijvfwtmdnmp")
    public suspend fun statements(vararg values: RuleGroupRuleStatementArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    internal fun build(): RuleGroupRuleStatementNotStatementArgs =
        RuleGroupRuleStatementNotStatementArgs(
            statements = statements ?: throw PulumiNullFieldException("statements"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementNotStatementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementNotStatementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property statements The statements to combine.
 */
public data class RuleGroupRuleStatementNotStatementArgs(
    public val statements: Output<List<RuleGroupRuleStatementArgs>>,
) : ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementNotStatementArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementNotStatementArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementNotStatementArgs.builder()
            .statements(
                statements.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RuleGroupRuleStatementNotStatementArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementNotStatementArgsBuilder internal constructor() {
    private var statements: Output<List<RuleGroupRuleStatementArgs>>? = null

    /**
     * @param value The statements to combine.
     */
    @JvmName("txiewffwyvsvuoxc")
    public suspend fun statements(`value`: Output<List<RuleGroupRuleStatementArgs>>) {
        this.statements = value
    }

    @JvmName("ssbtvcubgadcmytv")
    public suspend fun statements(vararg values: Output<RuleGroupRuleStatementArgs>) {
        this.statements = Output.all(values.asList())
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("vdncyledwgjafkpt")
    public suspend fun statements(values: List<Output<RuleGroupRuleStatementArgs>>) {
        this.statements = Output.all(values)
    }

    /**
     * @param value The statements to combine.
     */
    @JvmName("wwgbngbwiuciqqpb")
    public suspend fun statements(`value`: List<RuleGroupRuleStatementArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("ifqqhfudbqaksdna")
    public suspend fun statements(argument: List<suspend RuleGroupRuleStatementArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RuleGroupRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("ebqmrjsgbvqnvkpm")
    public suspend fun statements(vararg argument: suspend RuleGroupRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            RuleGroupRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("uykbdythxwigcers")
    public suspend fun statements(argument: suspend RuleGroupRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RuleGroupRuleStatementArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("fotxanceqgyukgxg")
    public suspend fun statements(vararg values: RuleGroupRuleStatementArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    internal fun build(): RuleGroupRuleStatementNotStatementArgs =
        RuleGroupRuleStatementNotStatementArgs(
            statements = statements ?: throw PulumiNullFieldException("statements"),
        )
}
